@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Dist::Zilla;
 
@@ -62,8 +62,11 @@ use Dist::Zilla::Plugin::Test::Version;
 
 use Moose;
 
-with 'Dist::Zilla::Role::PluginBundle::Easy',
-    'Dist::Zilla::Role::PluginBundle::PluginRemover';
+with(
+    'Dist::Zilla::Role::PluginBundle::Config::Slicer',
+    'Dist::Zilla::Role::PluginBundle::Easy',
+    'Dist::Zilla::Role::PluginBundle::PluginRemover',
+);
 
 has dist => (
     is       => 'ro',
@@ -222,7 +225,8 @@ sub _build_plugins {
         ],
         [
             AutoPrereqs => {
-                $self->_has_prereqs_skip() ? ( skip => $self->prereqs_skip() )
+                $self->_has_prereqs_skip()
+                ? ( skip => $self->prereqs_skip() )
                 : ()
             },
         ],
@@ -440,7 +444,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MaxMind's plugin bundle
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =for Pod::Coverage .*
 
@@ -448,6 +452,12 @@ version 0.11
 
 Dave Rolsky <drolsky@maxmind.com>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mateu X Hunter
+
+Mateu X Hunter <mhunter@maxmind.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 - 2015 by MaxMind, Inc..
